class Workspace:
    path: str


class System:
    pass


class Goal:
    pass


class Intelligence:
    input_types: list[str]
    output_types: list[str]


class Auth:
    pass


class Monitor:
    pass


class Logger:
    pass
